@@ -6,7 +6,7 @@ use Carp;
 use File::ShareDir ':ALL';
 use Path::Tiny;
 
-our $VERSION = '0.009_02';
+our $VERSION = '0.011_1';
 
 sub startup {
     my $self = shift;
@@ -39,13 +39,14 @@ sub startup {
 ###############################################################################
     push @{$self->plugins->namespaces}, 'App::skryf::Plugin';
     $self->plugin('Blog' => {authentication => $self->session('user')});
+    $self->plugin('Wiki' => {authentication => $self->session('user')});
 
 ###############################################################################
 # Define template, media, static paths
 ###############################################################################
     my $template_directory = undef;
     my $media_directory    = undef;
-    if ($self->mode eq "development") {
+    if ($self->mode eq "development" || !defined($cfg->{template_directory})) {
         $template_directory = path(dist_dir('App-skryf'), 'templates');
         $media_directory    = path(dist_dir('App-skryf'), 'public');
     }
@@ -74,11 +75,7 @@ sub startup {
     $r->get('/login')->to('login#login')->name('login');
     $r->get('/logout')->to('login#logout')->name('logout');
     $r->post('/auth')->to('login#auth')->name('auth');
-
-    # Static page view
-    $r->get('/:slug')->to('blog#static_page')->name('static_page');
-}
-
+  }
 1;
 
 __END__
@@ -123,17 +120,17 @@ I like L<http://perlbrew.pl>, but, whatever you're comfortable with. I won't jud
 
 By default B<skryf> will look in dist_dir for templates and media. To override that
 make sure I<~/.skryf.conf> points to the locations of your templates and media.
-For example, this is a simple directory structure for managing your blog media and templates.
+For example: 
 
     $ mkdir -p ~/blog/{templates,public}
 
 Edit ~/.skryf.conf to reflect those directories in I<media_directory> and 
-I<public_directory>.
+I<media_directory>.
 
     template_directory => '~/blog/templates',
     media_directory    => '~/blog/public',
 
-So B<~/blog/templates/{post.html.ep,index.html.ep,about.html.ep}> and B<~/blog/public/style.css>
+So B<~/blog/templates/blog/detail.html.ep> and B<~/blog/public/style.css>
 
 =head1 DEPLOY
 
